@@ -494,58 +494,112 @@ ggplot = make_master_binding()
 
 
 # generated by make_ggplot2_binding
-# ggplot2 library version: 1.0.1
-# date: Fri Jul 31 14:09:30 2015
+# ggplot2 library version: 3.3.5
+# date: Mon Jul 19 10:35:38 2021
 aes = make_ggplot2_binding("aes")
+aes_ = make_ggplot2_binding("aes_")
 aes_all = make_ggplot2_binding("aes_all")
 aes_auto = make_ggplot2_binding("aes_auto")
 aes_string = make_ggplot2_binding("aes_string")
+after_scale = make_ggplot2_binding("after_scale")
+after_stat = make_ggplot2_binding("after_stat")
+alpha = make_ggplot2_binding("alpha")
 annotate = make_ggplot2_binding("annotate")
 annotation_custom = make_ggplot2_binding("annotation_custom")
 annotation_logticks = make_ggplot2_binding("annotation_logticks")
 annotation_map = make_ggplot2_binding("annotation_map")
 annotation_raster = make_ggplot2_binding("annotation_raster")
+arrow = make_ggplot2_binding("arrow")
+as_label = make_ggplot2_binding("as_label")
+as_labeller = make_ggplot2_binding("as_labeller")
+autolayer = make_ggplot2_binding("autolayer")
 autoplot = make_ggplot2_binding("autoplot")
+binned_scale = make_ggplot2_binding("binned_scale")
 borders = make_ggplot2_binding("borders")
 calc_element = make_ggplot2_binding("calc_element")
+combine_vars = make_ggplot2_binding("combine_vars")
 continuous_scale = make_ggplot2_binding("continuous_scale")
-coord = make_ggplot2_binding("coord")
 coord_cartesian = make_ggplot2_binding("coord_cartesian")
 coord_equal = make_ggplot2_binding("coord_equal")
 coord_fixed = make_ggplot2_binding("coord_fixed")
 coord_flip = make_ggplot2_binding("coord_flip")
 coord_map = make_ggplot2_binding("coord_map")
+coord_munch = make_ggplot2_binding("coord_munch")
 coord_polar = make_ggplot2_binding("coord_polar")
 coord_quickmap = make_ggplot2_binding("coord_quickmap")
+coord_sf = make_ggplot2_binding("coord_sf")
 coord_trans = make_ggplot2_binding("coord_trans")
 cut_interval = make_ggplot2_binding("cut_interval")
 cut_number = make_ggplot2_binding("cut_number")
+cut_width = make_ggplot2_binding("cut_width")
+derive = make_ggplot2_binding("derive")
 discrete_scale = make_ggplot2_binding("discrete_scale")
+draw_key_abline = make_ggplot2_binding("draw_key_abline")
+draw_key_blank = make_ggplot2_binding("draw_key_blank")
+draw_key_boxplot = make_ggplot2_binding("draw_key_boxplot")
+draw_key_crossbar = make_ggplot2_binding("draw_key_crossbar")
+draw_key_dotplot = make_ggplot2_binding("draw_key_dotplot")
+draw_key_label = make_ggplot2_binding("draw_key_label")
+draw_key_path = make_ggplot2_binding("draw_key_path")
+draw_key_point = make_ggplot2_binding("draw_key_point")
+draw_key_pointrange = make_ggplot2_binding("draw_key_pointrange")
+draw_key_polygon = make_ggplot2_binding("draw_key_polygon")
+draw_key_rect = make_ggplot2_binding("draw_key_rect")
+draw_key_smooth = make_ggplot2_binding("draw_key_smooth")
+draw_key_text = make_ggplot2_binding("draw_key_text")
+draw_key_timeseries = make_ggplot2_binding("draw_key_timeseries")
+draw_key_vline = make_ggplot2_binding("draw_key_vline")
+draw_key_vpath = make_ggplot2_binding("draw_key_vpath")
+dup_axis = make_ggplot2_binding("dup_axis")
+el_def = make_ggplot2_binding("el_def")
 element_blank = make_ggplot2_binding("element_blank")
+element_grob = make_ggplot2_binding("element_grob")
 element_line = make_ggplot2_binding("element_line")
 element_rect = make_ggplot2_binding("element_rect")
+element_render = make_ggplot2_binding("element_render")
 element_text = make_ggplot2_binding("element_text")
+enexpr = make_ggplot2_binding("enexpr")
+enexprs = make_ggplot2_binding("enexprs")
+enquo = make_ggplot2_binding("enquo")
+enquos = make_ggplot2_binding("enquos")
+ensym = make_ggplot2_binding("ensym")
+ensyms = make_ggplot2_binding("ensyms")
 expand_limits = make_ggplot2_binding("expand_limits")
-facet = make_ggplot2_binding("facet")
+expand_scale = make_ggplot2_binding("expand_scale")
+expansion = make_ggplot2_binding("expansion")
+expr = make_ggplot2_binding("expr")
 facet_null = make_ggplot2_binding("facet_null")
+find_panel = make_ggplot2_binding("find_panel")
+flip_data = make_ggplot2_binding("flip_data")
+flipped_names = make_ggplot2_binding("flipped_names")
 geom_abline = make_ggplot2_binding("geom_abline")
 geom_area = make_ggplot2_binding("geom_area")
 geom_bar = make_ggplot2_binding("geom_bar")
+geom_bin_2d = make_ggplot2_binding("geom_bin_2d")
 geom_bin2d = make_ggplot2_binding("geom_bin2d")
 geom_blank = make_ggplot2_binding("geom_blank")
 geom_boxplot = make_ggplot2_binding("geom_boxplot")
+geom_col = make_ggplot2_binding("geom_col")
 geom_contour = make_ggplot2_binding("geom_contour")
+geom_contour_filled = make_ggplot2_binding("geom_contour_filled")
+geom_count = make_ggplot2_binding("geom_count")
 geom_crossbar = make_ggplot2_binding("geom_crossbar")
+geom_curve = make_ggplot2_binding("geom_curve")
 geom_density = make_ggplot2_binding("geom_density")
+geom_density_2d = make_ggplot2_binding("geom_density_2d")
+geom_density_2d_filled = make_ggplot2_binding("geom_density_2d_filled")
 geom_density2d = make_ggplot2_binding("geom_density2d")
+geom_density2d_filled = make_ggplot2_binding("geom_density2d_filled")
 geom_dotplot = make_ggplot2_binding("geom_dotplot")
 geom_errorbar = make_ggplot2_binding("geom_errorbar")
 geom_errorbarh = make_ggplot2_binding("geom_errorbarh")
 geom_freqpoly = make_ggplot2_binding("geom_freqpoly")
+geom_function = make_ggplot2_binding("geom_function")
 geom_hex = make_ggplot2_binding("geom_hex")
 geom_histogram = make_ggplot2_binding("geom_histogram")
 geom_hline = make_ggplot2_binding("geom_hline")
 geom_jitter = make_ggplot2_binding("geom_jitter")
+geom_label = make_ggplot2_binding("geom_label")
 geom_line = make_ggplot2_binding("geom_line")
 geom_linerange = make_ggplot2_binding("geom_linerange")
 geom_map = make_ggplot2_binding("geom_map")
@@ -553,58 +607,105 @@ geom_path = make_ggplot2_binding("geom_path")
 geom_point = make_ggplot2_binding("geom_point")
 geom_pointrange = make_ggplot2_binding("geom_pointrange")
 geom_polygon = make_ggplot2_binding("geom_polygon")
+geom_qq = make_ggplot2_binding("geom_qq")
+geom_qq_line = make_ggplot2_binding("geom_qq_line")
 geom_quantile = make_ggplot2_binding("geom_quantile")
 geom_raster = make_ggplot2_binding("geom_raster")
 geom_rect = make_ggplot2_binding("geom_rect")
 geom_ribbon = make_ggplot2_binding("geom_ribbon")
 geom_rug = make_ggplot2_binding("geom_rug")
 geom_segment = make_ggplot2_binding("geom_segment")
+geom_sf = make_ggplot2_binding("geom_sf")
+geom_sf_label = make_ggplot2_binding("geom_sf_label")
+geom_sf_text = make_ggplot2_binding("geom_sf_text")
 geom_smooth = make_ggplot2_binding("geom_smooth")
+geom_spoke = make_ggplot2_binding("geom_spoke")
 geom_step = make_ggplot2_binding("geom_step")
 geom_text = make_ggplot2_binding("geom_text")
-geom_text_repel = make_ggplot2_binding("geom_text_repel")
 geom_tile = make_ggplot2_binding("geom_tile")
 geom_violin = make_ggplot2_binding("geom_violin")
 geom_vline = make_ggplot2_binding("geom_vline")
-ggfluctuation = make_ggplot2_binding("ggfluctuation")
-ggmissing = make_ggplot2_binding("ggmissing")
-ggorder = make_ggplot2_binding("ggorder")
-ggpcp = make_ggplot2_binding("ggpcp")
+get_alt_text = make_ggplot2_binding("get_alt_text")
+get_element_tree = make_ggplot2_binding("get_element_tree")
+ggplot = make_ggplot2_binding("ggplot")
+ggplot_add = make_ggplot2_binding("ggplot_add")
+ggproto = make_ggplot2_binding("ggproto")
+ggproto_parent = make_ggplot2_binding("ggproto_parent")
 ggtitle = make_ggplot2_binding("ggtitle")
+guide_axis = make_ggplot2_binding("guide_axis")
+guide_bins = make_ggplot2_binding("guide_bins")
 guide_colorbar = make_ggplot2_binding("guide_colorbar")
+guide_colorsteps = make_ggplot2_binding("guide_colorsteps")
 guide_colourbar = make_ggplot2_binding("guide_colourbar")
+guide_coloursteps = make_ggplot2_binding("guide_coloursteps")
+guide_gengrob = make_ggplot2_binding("guide_gengrob")
+guide_geom = make_ggplot2_binding("guide_geom")
 guide_legend = make_ggplot2_binding("guide_legend")
+guide_merge = make_ggplot2_binding("guide_merge")
+guide_none = make_ggplot2_binding("guide_none")
+guide_train = make_ggplot2_binding("guide_train")
+guide_transform = make_ggplot2_binding("guide_transform")
 guides = make_ggplot2_binding("guides")
+has_flipped_aes = make_ggplot2_binding("has_flipped_aes")
+is.Coord = make_ggplot2_binding("is.Coord")
+is.ggproto = make_ggplot2_binding("is.ggproto")
 label_both = make_ggplot2_binding("label_both")
 label_bquote = make_ggplot2_binding("label_bquote")
+label_context = make_ggplot2_binding("label_context")
 label_parsed = make_ggplot2_binding("label_parsed")
 label_value = make_ggplot2_binding("label_value")
 label_wrap_gen = make_ggplot2_binding("label_wrap_gen")
 labeller = make_ggplot2_binding("labeller")
 labs = make_ggplot2_binding("labs")
 layer = make_ggplot2_binding("layer")
-opts = make_ggplot2_binding("opts")
-plotmatrix = make_ggplot2_binding("plotmatrix")
+layer_data = make_ggplot2_binding("layer_data")
+layer_grob = make_ggplot2_binding("layer_grob")
+layer_scales = make_ggplot2_binding("layer_scales")
+layer_sf = make_ggplot2_binding("layer_sf")
+lims = make_ggplot2_binding("lims")
+margin = make_ggplot2_binding("margin")
+max_height = make_ggplot2_binding("max_height")
+max_width = make_ggplot2_binding("max_width")
+merge_element = make_ggplot2_binding("merge_element")
+panel_cols = make_ggplot2_binding("panel_cols")
+panel_rows = make_ggplot2_binding("panel_rows")
 position_dodge = make_ggplot2_binding("position_dodge")
+position_dodge2 = make_ggplot2_binding("position_dodge2")
 position_fill = make_ggplot2_binding("position_fill")
 position_identity = make_ggplot2_binding("position_identity")
 position_jitter = make_ggplot2_binding("position_jitter")
 position_jitterdodge = make_ggplot2_binding("position_jitterdodge")
+position_nudge = make_ggplot2_binding("position_nudge")
 position_stack = make_ggplot2_binding("position_stack")
 qplot = make_ggplot2_binding("qplot")
 quickplot = make_ggplot2_binding("quickplot")
+quo = make_ggplot2_binding("quo")
+quo_name = make_ggplot2_binding("quo_name")
+quos = make_ggplot2_binding("quos")
+register_theme_elements = make_ggplot2_binding("register_theme_elements")
 rel = make_ggplot2_binding("rel")
+remove_missing = make_ggplot2_binding("remove_missing")
+render_axes = make_ggplot2_binding("render_axes")
+render_strips = make_ggplot2_binding("render_strips")
+reset_theme_settings = make_ggplot2_binding("reset_theme_settings")
 resolution = make_ggplot2_binding("resolution")
 scale_alpha = make_ggplot2_binding("scale_alpha")
+scale_alpha_binned = make_ggplot2_binding("scale_alpha_binned")
 scale_alpha_continuous = make_ggplot2_binding("scale_alpha_continuous")
+scale_alpha_date = make_ggplot2_binding("scale_alpha_date")
+scale_alpha_datetime = make_ggplot2_binding("scale_alpha_datetime")
 scale_alpha_discrete = make_ggplot2_binding("scale_alpha_discrete")
 scale_alpha_identity = make_ggplot2_binding("scale_alpha_identity")
 scale_alpha_manual = make_ggplot2_binding("scale_alpha_manual")
-scale_area = make_ggplot2_binding("scale_area")
+scale_alpha_ordinal = make_ggplot2_binding("scale_alpha_ordinal")
+scale_color_binned = make_ggplot2_binding("scale_color_binned")
 scale_color_brewer = make_ggplot2_binding("scale_color_brewer")
 scale_color_continuous = make_ggplot2_binding("scale_color_continuous")
+scale_color_date = make_ggplot2_binding("scale_color_date")
+scale_color_datetime = make_ggplot2_binding("scale_color_datetime")
 scale_color_discrete = make_ggplot2_binding("scale_color_discrete")
 scale_color_distiller = make_ggplot2_binding("scale_color_distiller")
+scale_color_fermenter = make_ggplot2_binding("scale_color_fermenter")
 scale_color_gradient = make_ggplot2_binding("scale_color_gradient")
 scale_color_gradient2 = make_ggplot2_binding("scale_color_gradient2")
 scale_color_gradientn = make_ggplot2_binding("scale_color_gradientn")
@@ -612,10 +713,21 @@ scale_color_grey = make_ggplot2_binding("scale_color_grey")
 scale_color_hue = make_ggplot2_binding("scale_color_hue")
 scale_color_identity = make_ggplot2_binding("scale_color_identity")
 scale_color_manual = make_ggplot2_binding("scale_color_manual")
+scale_color_ordinal = make_ggplot2_binding("scale_color_ordinal")
+scale_color_steps = make_ggplot2_binding("scale_color_steps")
+scale_color_steps2 = make_ggplot2_binding("scale_color_steps2")
+scale_color_stepsn = make_ggplot2_binding("scale_color_stepsn")
+scale_color_viridis_b = make_ggplot2_binding("scale_color_viridis_b")
+scale_color_viridis_c = make_ggplot2_binding("scale_color_viridis_c")
+scale_color_viridis_d = make_ggplot2_binding("scale_color_viridis_d")
+scale_colour_binned = make_ggplot2_binding("scale_colour_binned")
 scale_colour_brewer = make_ggplot2_binding("scale_colour_brewer")
 scale_colour_continuous = make_ggplot2_binding("scale_colour_continuous")
+scale_colour_date = make_ggplot2_binding("scale_colour_date")
+scale_colour_datetime = make_ggplot2_binding("scale_colour_datetime")
 scale_colour_discrete = make_ggplot2_binding("scale_colour_discrete")
 scale_colour_distiller = make_ggplot2_binding("scale_colour_distiller")
+scale_colour_fermenter = make_ggplot2_binding("scale_colour_fermenter")
 scale_colour_gradient = make_ggplot2_binding("scale_colour_gradient")
 scale_colour_gradient2 = make_ggplot2_binding("scale_colour_gradient2")
 scale_colour_gradientn = make_ggplot2_binding("scale_colour_gradientn")
@@ -623,10 +735,24 @@ scale_colour_grey = make_ggplot2_binding("scale_colour_grey")
 scale_colour_hue = make_ggplot2_binding("scale_colour_hue")
 scale_colour_identity = make_ggplot2_binding("scale_colour_identity")
 scale_colour_manual = make_ggplot2_binding("scale_colour_manual")
+scale_colour_ordinal = make_ggplot2_binding("scale_colour_ordinal")
+scale_colour_steps = make_ggplot2_binding("scale_colour_steps")
+scale_colour_steps2 = make_ggplot2_binding("scale_colour_steps2")
+scale_colour_stepsn = make_ggplot2_binding("scale_colour_stepsn")
+scale_colour_viridis_b = make_ggplot2_binding("scale_colour_viridis_b")
+scale_colour_viridis_c = make_ggplot2_binding("scale_colour_viridis_c")
+scale_colour_viridis_d = make_ggplot2_binding("scale_colour_viridis_d")
+scale_continuous_identity = make_ggplot2_binding("scale_continuous_identity")
+scale_discrete_identity = make_ggplot2_binding("scale_discrete_identity")
+scale_discrete_manual = make_ggplot2_binding("scale_discrete_manual")
+scale_fill_binned = make_ggplot2_binding("scale_fill_binned")
 scale_fill_brewer = make_ggplot2_binding("scale_fill_brewer")
 scale_fill_continuous = make_ggplot2_binding("scale_fill_continuous")
+scale_fill_date = make_ggplot2_binding("scale_fill_date")
+scale_fill_datetime = make_ggplot2_binding("scale_fill_datetime")
 scale_fill_discrete = make_ggplot2_binding("scale_fill_discrete")
 scale_fill_distiller = make_ggplot2_binding("scale_fill_distiller")
+scale_fill_fermenter = make_ggplot2_binding("scale_fill_fermenter")
 scale_fill_gradient = make_ggplot2_binding("scale_fill_gradient")
 scale_fill_gradient2 = make_ggplot2_binding("scale_fill_gradient2")
 scale_fill_gradientn = make_ggplot2_binding("scale_fill_gradientn")
@@ -634,22 +760,40 @@ scale_fill_grey = make_ggplot2_binding("scale_fill_grey")
 scale_fill_hue = make_ggplot2_binding("scale_fill_hue")
 scale_fill_identity = make_ggplot2_binding("scale_fill_identity")
 scale_fill_manual = make_ggplot2_binding("scale_fill_manual")
+scale_fill_ordinal = make_ggplot2_binding("scale_fill_ordinal")
+scale_fill_steps = make_ggplot2_binding("scale_fill_steps")
+scale_fill_steps2 = make_ggplot2_binding("scale_fill_steps2")
+scale_fill_stepsn = make_ggplot2_binding("scale_fill_stepsn")
+scale_fill_viridis_b = make_ggplot2_binding("scale_fill_viridis_b")
+scale_fill_viridis_c = make_ggplot2_binding("scale_fill_viridis_c")
+scale_fill_viridis_d = make_ggplot2_binding("scale_fill_viridis_d")
 scale_linetype = make_ggplot2_binding("scale_linetype")
+scale_linetype_binned = make_ggplot2_binding("scale_linetype_binned")
 scale_linetype_continuous = make_ggplot2_binding("scale_linetype_continuous")
 scale_linetype_discrete = make_ggplot2_binding("scale_linetype_discrete")
 scale_linetype_identity = make_ggplot2_binding("scale_linetype_identity")
 scale_linetype_manual = make_ggplot2_binding("scale_linetype_manual")
+scale_radius = make_ggplot2_binding("scale_radius")
 scale_shape = make_ggplot2_binding("scale_shape")
+scale_shape_binned = make_ggplot2_binding("scale_shape_binned")
 scale_shape_continuous = make_ggplot2_binding("scale_shape_continuous")
 scale_shape_discrete = make_ggplot2_binding("scale_shape_discrete")
 scale_shape_identity = make_ggplot2_binding("scale_shape_identity")
 scale_shape_manual = make_ggplot2_binding("scale_shape_manual")
+scale_shape_ordinal = make_ggplot2_binding("scale_shape_ordinal")
 scale_size = make_ggplot2_binding("scale_size")
 scale_size_area = make_ggplot2_binding("scale_size_area")
+scale_size_binned = make_ggplot2_binding("scale_size_binned")
+scale_size_binned_area = make_ggplot2_binding("scale_size_binned_area")
 scale_size_continuous = make_ggplot2_binding("scale_size_continuous")
+scale_size_date = make_ggplot2_binding("scale_size_date")
+scale_size_datetime = make_ggplot2_binding("scale_size_datetime")
 scale_size_discrete = make_ggplot2_binding("scale_size_discrete")
 scale_size_identity = make_ggplot2_binding("scale_size_identity")
 scale_size_manual = make_ggplot2_binding("scale_size_manual")
+scale_size_ordinal = make_ggplot2_binding("scale_size_ordinal")
+scale_type = make_ggplot2_binding("scale_type")
+scale_x_binned = make_ggplot2_binding("scale_x_binned")
 scale_x_continuous = make_ggplot2_binding("scale_x_continuous")
 scale_x_date = make_ggplot2_binding("scale_x_date")
 scale_x_datetime = make_ggplot2_binding("scale_x_datetime")
@@ -657,6 +801,8 @@ scale_x_discrete = make_ggplot2_binding("scale_x_discrete")
 scale_x_log10 = make_ggplot2_binding("scale_x_log10")
 scale_x_reverse = make_ggplot2_binding("scale_x_reverse")
 scale_x_sqrt = make_ggplot2_binding("scale_x_sqrt")
+scale_x_time = make_ggplot2_binding("scale_x_time")
+scale_y_binned = make_ggplot2_binding("scale_y_binned")
 scale_y_continuous = make_ggplot2_binding("scale_y_continuous")
 scale_y_date = make_ggplot2_binding("scale_y_date")
 scale_y_datetime = make_ggplot2_binding("scale_y_datetime")
@@ -664,52 +810,75 @@ scale_y_discrete = make_ggplot2_binding("scale_y_discrete")
 scale_y_log10 = make_ggplot2_binding("scale_y_log10")
 scale_y_reverse = make_ggplot2_binding("scale_y_reverse")
 scale_y_sqrt = make_ggplot2_binding("scale_y_sqrt")
-stat_abline = make_ggplot2_binding("stat_abline")
+scale_y_time = make_ggplot2_binding("scale_y_time")
+sec_axis = make_ggplot2_binding("sec_axis")
+set_last_plot = make_ggplot2_binding("set_last_plot")
+sf_transform_xy = make_ggplot2_binding("sf_transform_xy")
+stage = make_ggplot2_binding("stage")
+standardise_aes_names = make_ggplot2_binding("standardise_aes_names")
+stat = make_ggplot2_binding("stat")
 stat_bin = make_ggplot2_binding("stat_bin")
+stat_bin_2d = make_ggplot2_binding("stat_bin_2d")
+stat_bin_hex = make_ggplot2_binding("stat_bin_hex")
 stat_bin2d = make_ggplot2_binding("stat_bin2d")
-stat_bindot = make_ggplot2_binding("stat_bindot")
 stat_binhex = make_ggplot2_binding("stat_binhex")
 stat_boxplot = make_ggplot2_binding("stat_boxplot")
 stat_contour = make_ggplot2_binding("stat_contour")
+stat_contour_filled = make_ggplot2_binding("stat_contour_filled")
+stat_count = make_ggplot2_binding("stat_count")
 stat_density = make_ggplot2_binding("stat_density")
+stat_density_2d = make_ggplot2_binding("stat_density_2d")
+stat_density_2d_filled = make_ggplot2_binding("stat_density_2d_filled")
 stat_density2d = make_ggplot2_binding("stat_density2d")
+stat_density2d_filled = make_ggplot2_binding("stat_density2d_filled")
 stat_ecdf = make_ggplot2_binding("stat_ecdf")
 stat_ellipse = make_ggplot2_binding("stat_ellipse")
 stat_function = make_ggplot2_binding("stat_function")
-stat_hline = make_ggplot2_binding("stat_hline")
 stat_identity = make_ggplot2_binding("stat_identity")
 stat_qq = make_ggplot2_binding("stat_qq")
+stat_qq_line = make_ggplot2_binding("stat_qq_line")
 stat_quantile = make_ggplot2_binding("stat_quantile")
+stat_sf = make_ggplot2_binding("stat_sf")
+stat_sf_coordinates = make_ggplot2_binding("stat_sf_coordinates")
 stat_smooth = make_ggplot2_binding("stat_smooth")
 stat_spoke = make_ggplot2_binding("stat_spoke")
 stat_sum = make_ggplot2_binding("stat_sum")
 stat_summary = make_ggplot2_binding("stat_summary")
+stat_summary_2d = make_ggplot2_binding("stat_summary_2d")
+stat_summary_bin = make_ggplot2_binding("stat_summary_bin")
 stat_summary_hex = make_ggplot2_binding("stat_summary_hex")
 stat_summary2d = make_ggplot2_binding("stat_summary2d")
 stat_unique = make_ggplot2_binding("stat_unique")
-stat_vline = make_ggplot2_binding("stat_vline")
 stat_ydensity = make_ggplot2_binding("stat_ydensity")
+summarise_coord = make_ggplot2_binding("summarise_coord")
+summarise_layers = make_ggplot2_binding("summarise_layers")
+summarise_layout = make_ggplot2_binding("summarise_layout")
+sym = make_ggplot2_binding("sym")
+syms = make_ggplot2_binding("syms")
 theme = make_ggplot2_binding("theme")
-theme_blank = make_ggplot2_binding("theme_blank")
 theme_bw = make_ggplot2_binding("theme_bw")
 theme_classic = make_ggplot2_binding("theme_classic")
+theme_dark = make_ggplot2_binding("theme_dark")
 theme_get = make_ggplot2_binding("theme_get")
 theme_gray = make_ggplot2_binding("theme_gray")
 theme_grey = make_ggplot2_binding("theme_grey")
 theme_light = make_ggplot2_binding("theme_light")
-theme_line = make_ggplot2_binding("theme_line")
 theme_linedraw = make_ggplot2_binding("theme_linedraw")
 theme_minimal = make_ggplot2_binding("theme_minimal")
-theme_rect = make_ggplot2_binding("theme_rect")
-theme_segment = make_ggplot2_binding("theme_segment")
+theme_replace = make_ggplot2_binding("theme_replace")
 theme_set = make_ggplot2_binding("theme_set")
-theme_text = make_ggplot2_binding("theme_text")
+theme_test = make_ggplot2_binding("theme_test")
 theme_update = make_ggplot2_binding("theme_update")
-update_element = make_ggplot2_binding("update_element")
+theme_void = make_ggplot2_binding("theme_void")
+transform_position = make_ggplot2_binding("transform_position")
+unit = make_ggplot2_binding("unit")
 update_geom_defaults = make_ggplot2_binding("update_geom_defaults")
 update_labels = make_ggplot2_binding("update_labels")
 update_stat_defaults = make_ggplot2_binding("update_stat_defaults")
+vars = make_ggplot2_binding("vars")
+wrap_dims = make_ggplot2_binding("wrap_dims")
 xlab = make_ggplot2_binding("xlab")
 xlim = make_ggplot2_binding("xlim")
 ylab = make_ggplot2_binding("ylab")
 ylim = make_ggplot2_binding("ylim")
+zeroGrob = make_ggplot2_binding("zeroGrob")
